# RSS Namespace Extension for Podcast (xmlns:podcast DTD)

A wholistic RSS namespace for podcasting that is meant to synthesize the fragmented world of podcast namespaces. As elements are canonized, they will be added to this document so developers can begin implementation. The specifications below are considered locked and the team will prioritize backward compatibility. We are operating under the [Rules for Standards-Makers](http://scripting.com/2017/05/09/rulesForStandardsmakers.html).

If your application generates RSS feeds and you implement one or more elements below, you will need to link this DTD in your XML.
`<rss version="2.0" xmlns:podcast="https://github.com/Podcastindex-org/podcast-namespace/blob/main/docs/1.0.md">`
# Podcast Tags
Each tag below exists in the podcast namespace within the specified parent. All attributes are required unless explicitly specified as optional.

Anywhere the url of a hyper-text based resource is specified, it must be given as `https:` and not `http:`.

<br><br>

## Transcript
`<podcast:transcript>`
This tag is used to link to a transcript or closed captions file. Multiple tags can be present for multiple transcript formats.

#### Parent
`<item>`

#### Count
Multiple

#### Attributes
 - **url:** URL of the podcast transcript.

 - **type:** Mime type of the file such as `text/plain`, `text/html`, `application/srt`, `application/json`

 - **language (optional):** The language of the linked transcript. If there is no language attribute given, the linked file is assumed to be the same language that is specified by the RSS `<language>` element.

 - **rel (optional):** If the rel="captions" attribute is present, the linked file is considered to be a closed captions file, regardless of what the mime type is.  In that scenario, time codes are assumed to be present in the file in some capacity.

#### Examples
`<podcast:transcript url="https://example.com/episode1/transcript.html" type="text/html" />`

`<podcast:transcript url="https://example.com/episode1/transcript.srt" type="text/srt" rel="captions" />`

`<podcast:transcript url="https://example.com/episode1/transcript.json" type="application/json" language="es" rel="captions" />`

Detailed file format information and example files are [here](../transcripts/transcripts.md).

<br><br>

## Locked
`<podcast:locked>`
This tag may be set to `yes` or `no`. The purpose is to tell other podcast platforms whether they are allowed to import this feed. A value of `yes` means that any attempt to import this feed into a new platform should be rejected. It is expected
that podcast hosting providers will enable a toggle in their GUI to allow their users to turn feed transfer lock on or off. When importing a feed, if the hosting provider has already verified the owner="" email address on their own system, and the
email matches what is listed in this tag, it is safe to import the feed.

#### Parent
`<channel>`

#### Count
Single

#### Attributes
 - **owner:** The owner attribute is an email address that can be used to verify ownership of this feed during move and import operations. This could be a public email or a virtual email address at the hosting provider that redirects to the owner's true email address. This is a critical element, and it's expected that podcast hosting providers (if not providing virtual addresses) will allow setting this element's value in their GUI with an emphasis to their users of how important it is to have this be a valid, working email address.

#### Examples
`<podcast:locked owner="email@example.com">yes</podcast:locked>`

`<podcast:locked owner="email@example.com">no</podcast:locked>`

<br><br>

## Funding
`<podcast:funding>`
This tag lists possible donation/funding links for the podcast. The content of the tag is the recommended string to be used with the link.

#### Parent
`<channel>`

#### Count
Multiple

#### Attributes
 - **url:** The URL to be followed to fund the podcast.

#### Examples
`<podcast:funding url="https://www.example.com/donations">Support the show!</podcast:funding>`

`<podcast:funding url="https://www.example.com/members">Become a member!</podcast:funding>`

Please do not exceed `128 characters` for the node value or it may be truncated by aggregators.

<br><br>

## Chapters
`<podcast:chapters>`
Links to an external file (see example file) containing chapter data for the episode. See the [jsonChapters.md](https://github.com/Podcastindex-org/podcast-namespace/blob/main/chapters/jsonChapters.md) file for a description of the chapter file syntax. And, see the [example.json](https://github.com/Podcastindex-org/podcast-namespace/blob/main/chapters/example.json) example file for a real world example.

#### Parent
`<item>`

#### Count
Single

#### Attributes
 - **url:** The URL where the chapters file is located.
 - **type:** Mime type of file - JSON prefered, 'application/json+chapters'.

#### Examples
`<podcast:chapters url="https://example.com/episode1/chapters.json" type="application/json+chapters" />`

<br><br>

## Soundbite
`<podcast:soundbite>`
Points to one or more soundbites within a podcast episode. The intended use includes episodes previews, discoverability, audiogram generation, episode highlights, etc. It should be assumed that the audio/video source of the soundbite is the audio/video given in the item's `<enclosure>` element.

#### Parent
`<item>`

#### Count
Multiple

#### Attributes
 - **startTime:** The time where the soundbite begins
 - **duration:** How long is the soundbite (recommended between 15 and 120 seconds)
 - **node value (optional):** Used as free form string from the podcast creator to specify a title for the soundbite (null defaults to episode title)

#### Examples
`<podcast:soundbite startTime="73.0" duration="60.0" />`

`<podcast:soundbite startTime="1234.5" duration="42.25">Why the Podcast Namespace Matters</podcast:soundbite>`

Please do not exceed `128 characters` for the node value or it may be truncated by aggregators.

<br><br>
